# reait
RevEng.AI Toolkit

Analyse compiled executable binaries using the RevEng.AI API.



## Installation

Install the latest stable version using pip.

`pip install reait`

### Latest development version

`pip install -e .`

## Run

`reait --help`
